package com.demo;
import java.awt.Color;
import java.awt.GradientPaint;
import java.awt.Paint;

import org.jfree.chart.ChartFactory;
import org.jfree.chart.ChartPanel;
import org.jfree.chart.JFreeChart;
import org.jfree.chart.LegendItem;
import org.jfree.chart.LegendItemCollection;
import org.jfree.chart.axis.SubCategoryAxis;
import org.jfree.chart.plot.CategoryPlot;
import org.jfree.chart.plot.PlotOrientation;

import org.jfree.data.KeyToGroupMap;
import org.jfree.data.category.CategoryDataset;

import org.jfree.ui.ApplicationFrame;
import org.jfree.ui.RefineryUtilities;
import org.jfree.ui.GradientPaintTransformType;
import org.jfree.ui.StandardGradientPaintTransformer;

import org.jfree.chart.renderer.category.GroupedStackedBarRenderer;

public class BarChartStacked extends ApplicationFrame
{
	private static final long serialVersionUID = 1L;

	private static final  String TITLE = "Stacked Bar Chart";

	private final Color  COLOR_1 = new Color(0x32, 0x32, 0xFF);
	private final Color  COLOR_2 = new Color(0x32, 0xFF, 0x32);
	private final Color  COLOR_3 = new Color(0xFF, 0x32, 0x32);
	private final Color  COLOR_4 = new Color(0xFF, 0xFF, 0x32);
	
	private final Color  COLOR_1_ = new Color(0x96, 0x96, 0xFF);
	private final Color  COLOR_2_ = new Color(0x96, 0xFF, 0x96);
	private final Color  COLOR_3_ = new Color(0xFF, 0x96, 0x96);
	private final Color  COLOR_4_ = new Color(0xFF, 0xFF, 0x96);
	
	public BarChartStacked(final String title) 
    {
        super(title);
        CategoryDataset  dataset    = Dataset.createDataset3();
        JFreeChart       chart      = createChart(dataset);
        ChartPanel       chartPanel = new ChartPanel(chart);
        chartPanel.setPreferredSize(new java.awt.Dimension(590, 350));
        setContentPane(chartPanel);
    }
    
    private GradientPaint gradientPaint(Color color1, Color color2)
    {
    	return new GradientPaint(0.0f, 0.0f, color1, 0.0f, 0.0f, color2);
    }
    
    private JFreeChart createChart(final CategoryDataset dataset) 
    {
    	SubCategoryAxis           domainAxis;
    	GroupedStackedBarRenderer renderer;

        final JFreeChart chart = ChartFactory.createStackedBarChart(
            TITLE     ,               // chart title
            "Category",               // domain axis label
            null      ,               // range axis label
            dataset   ,               // data
            PlotOrientation.VERTICAL, // the plot orientation
            true,                     // legend
            true,                     // tooltips
            false                     // urls
        );
        
        KeyToGroupMap map = new KeyToGroupMap("G1");
        map.mapKeyToGroup("Чай (Офис 1)", "G1");
        map.mapKeyToGroup("Чай (Офис 2)", "G1");
        map.mapKeyToGroup("Чай (Офис 3)", "G1");
        map.mapKeyToGroup("Чай (Офис 4)", "G1");
        
        map.mapKeyToGroup("Кофе (Офис 1)", "G2");
        map.mapKeyToGroup("Кофе (Офис 2)", "G2");
        map.mapKeyToGroup("Кофе (Офис 3)", "G2");
        map.mapKeyToGroup("Кофе (Офис 4)", "G2");
        
        map.mapKeyToGroup("Коктейль (Офис 1)", "G3");
        map.mapKeyToGroup("Коктейль (Офис 2)", "G3");
        map.mapKeyToGroup("Коктейль (Офис 3)", "G3");
        map.mapKeyToGroup("Коктейль (Офис 4)", "G3");
        
        renderer = new GroupedStackedBarRenderer();
        renderer.setSeriesToGroupMap(map); 
        
        renderer.setItemMargin(0.0);
        Paint p1 = gradientPaint(COLOR_1, COLOR_1_);
        renderer.setSeriesPaint(0, p1);
        renderer.setSeriesPaint(4, p1);
        renderer.setSeriesPaint(8, p1);
         
        Paint p2 = gradientPaint(COLOR_2, COLOR_2_);
        renderer.setSeriesPaint(1, p2); 
        renderer.setSeriesPaint(5, p2); 
        renderer.setSeriesPaint(9, p2); 
        
        Paint p3 = gradientPaint(COLOR_3, COLOR_3_);
        renderer.setSeriesPaint(2, p3);
        renderer.setSeriesPaint(6, p3);
        renderer.setSeriesPaint(10, p3);
            
        Paint p4 = gradientPaint(COLOR_4, COLOR_4_);
        renderer.setSeriesPaint(3, p4);
        renderer.setSeriesPaint(7, p4);
        renderer.setSeriesPaint(11, p4);
        renderer.setGradientPaintTransformer(
            new StandardGradientPaintTransformer(
            		      GradientPaintTransformType.HORIZONTAL)
        );
        
        domainAxis = new SubCategoryAxis("Напитки / Месяц");
        domainAxis.setCategoryMargin(0.25);
        domainAxis.addSubCategory("Чай"     );
        domainAxis.addSubCategory("Кофе"    );
        domainAxis.addSubCategory("Коктейль");
        // Удаляем из диаграммы осевые линии и метки делений
        domainAxis.setAxisLineVisible (false);  // осевая линия
        domainAxis.setTickMarksVisible(false);  // метки деления оси 
        
        CategoryPlot plot = (CategoryPlot) chart.getPlot();
        plot.setDomainAxis(domainAxis);
        plot.setRenderer(renderer);
        plot.setFixedLegendItems(createLegendItems());
        
        plot.setBackgroundPaint (new Color(232, 232, 248));

        return chart;        
    }

    /**
     * Создание легенды для диаграммы
     * @return LegendItemCollection
     */
    private LegendItemCollection createLegendItems()
    {
    	LegendItemCollection legend = new LegendItemCollection();
    	LegendItem item1 = new LegendItem("Офис 1", COLOR_1); 
    	LegendItem item2 = new LegendItem("Офис 2", COLOR_2);
    	LegendItem item3 = new LegendItem("Офис 3", COLOR_3);
    	LegendItem item4 = new LegendItem("Офис 4", COLOR_4);
        legend.add(item1);
        legend.add(item2);
        legend.add(item3);
        legend.add(item4);
        return legend;
    }

    public static void main(final String[] args)
    {
        final BarChartStacked demo = new BarChartStacked(TITLE);
        demo.pack();
        RefineryUtilities.centerFrameOnScreen(demo);
        demo.setVisible(true);
    }
}
